@@ -1,5 +1,3 @@
-import json
-
 from sdccli.printer import print_list as _print_list, print_item as _print_item
 
 
@@ -27,7 +25,8 @@ def print_panel(panel):
 
 def print_panel_list(panel_list):
     for panel in panel_list:
-        panel["queryCount"] = len(panel["advancedQueries"]) if "advancedQueries" in panel else len(
-            panel["basicQueries"])
+        if "queryCount" in panel:
+            panel["queryCount"] = len(panel["advancedQueries"]) if "advancedQueries" in panel else len(
+                panel["basicQueries"])
 
     _print_list(panel_list, _list_keys)
